# Metano

For installation instructions and further information about Metano,
please visit [the project homepage](http://metano.tu-bs.de), where we also provide a detailed [manual](http://metano.tu-bs.de/?page=manual).

# MMTB
The [Metano Modeling Toolbox (MMTB)](http://mmtb.tu-bs.de) is a web-based toolbox that assists during model creation and analysis.
Many Metano tools (FBA, FVA, split-ratio, ...) can be used via MMTB without installation.
Furthermore, MMTB offers different visualizations for your metabolic models.

# License information
Metano is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Metano is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
[GNU General Public License](http://www.gnu.org/licenses/) for more details.

